@@ -16,6 +16,7 @@
 #endif
 #include "waifu2x.h"
 #include <time.h>
+#include <sys/timeb.h>
 #include "filesystem_utils.h"
 
 enum Waifu2xError {
@@ -41,11 +42,12 @@ public:
     unsigned long toW;
     unsigned long toH;
     float scale = 2;
+    int tileSize = 0;
 
-    clock_t startTick;
-    clock_t encodeTick;
-    clock_t procTick;
-    clock_t saveTick;
+    struct timeb startTick;
+    struct timeb encodeTick;
+    struct timeb procTick;
+    struct timeb saveTick;
     void* out = 0;
     int outSize = 0;
 };
@@ -146,7 +148,7 @@ private:
     std::queue<Task> tasks;
 };
 
-int waifu2x_addData(const unsigned char* data, unsigned int size, int callBack, int modelIndex, const char* format, unsigned long toW, unsigned long toH, float scale);
+int waifu2x_addData(const unsigned char* data, unsigned int size, int callBack, int modelIndex, const char* format, unsigned long toW, unsigned long toH, float scale, int);
 int waifu2x_getData(void*& out, unsigned long& outSize, double& tick, int& callBack, unsigned int timeout);
 int waifu2x_init();
 int waifu2x_init_set(int gpuId2, int threadNum);
