@@ -50,7 +50,7 @@ static PyMethodDef SpamMethods[] = {
     {"initSet",  (PyCFunction)waifu2x_py_init_set, METH_VARARGS | METH_KEYWORDS,
      "Init setting\ngpuId: getGpuInfo get index \nthreadNum: convert thread num \n"},
     {"add",  (PyCFunction)waifu2x_py_add, METH_VARARGS | METH_KEYWORDS,
-     "Add task, \ndata: img bytes \nmodelIndex: Model enum \nbackId: call back id \nformat(Option): export fmt, support bmp png jpg ico \nwidth(Option): export set width \nhigh(Option): export set high \nscale(Option): export set width and high\n"},
+     "Add task, \ndata: img bytes \nmodelIndex: Model enum \nbackId: call back id \nformat(Option): export fmt, support bmp png jpg ico \nwidth(Option): export set width \nhigh(Option): export set high \nscale(Option): export set width and high \ntileSize(Option): default Auto\n"},
     {"getGpuInfo",  (PyCFunction)waifu2x_py_get_info, METH_VARARGS,
      "Get gpu list\n"},
     {"remove",  (PyCFunction)waifu2x_py_remove, METH_VARARGS | METH_KEYWORDS,
@@ -64,7 +64,7 @@ static PyMethodDef SpamMethods[] = {
     {"stop",  waifu2x_py_stop, METH_VARARGS,
      "Kill thread\n"},
     {"getVersion",  waifu2x_py_version, METH_VARARGS,
-     "Get version\nProject: https://github.com/tonquer/waifu2x-vulkan \nVersion: v1.3 \n"},
+     "Get version\nProject: https://github.com/tonquer/waifu2x-vulkan \n"},
     {"setDebug",  waifu2x_py_set_debug, METH_VARARGS,
      "Set debug log\n True or False\n"},
      {"setDefaultPath",  waifu2x_py_set_path, METH_VARARGS,
@@ -83,5 +83,5 @@ static struct PyModuleDef spammodule = {
 
 static bool IsInit = false;
 static bool IsInitSet = false;
-static const char* Version = "1.0.5";
+static const char* Version = "1.0.7";
 #endif 
\ No newline at end of file
